==> netjfwatcher_jetty_1.0.2_plugins.zip: netjfwatcher/jetty/gui/AbstractEditorView.java <==
/*
 * Created on 2006/08/17
 *
 *
 * Copyright(c) 2006 Yoshimasa Matsumoto
 */
package netjfwatcher.jetty.gui;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.SubStatusLineManager;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorSite;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.part.EditorPart;


/**
 * Editor View`钊ۃNXłB
 *
 * @author Yoshimasa Matsumoto
 * @version 1.0
 */
public abstract class AbstractEditorView extends EditorPart {
    /* Xe[^XC}l[W */
    protected SubStatusLineManager statusLineManager;

    public AbstractEditorView() {
    }

    /**
     * PartControl𐶐܂B
     *
     * @param parent Composite
     */
    abstract public void createPartControl(Composite parent);

    /**
     * Xe[^XC\Zbg܂B
     *
     */
    protected abstract void setStatusLine();

    /**
     * tH[JXZbg̏łB
     */
    public void setFocus() {
    }

    /*
     *  (non-Javadoc)
     * @see org.eclipse.ui.ISaveablePart#isDirty()
     */
    public boolean isDirty() {
        return false;
    }

    /*
     *  (non-Javadoc)
     * @see org.eclipse.ui.ISaveablePart#doSave(org.eclipse.core.runtime.IProgressMonitor)
     */
    public void doSave(IProgressMonitor monitor) {
    }

    /*
     *  (non-Javadoc)
     * @see org.eclipse.ui.ISaveablePart#doSaveAs()
     */
    public void doSaveAs() {
    }

    /*
     *  (non-Javadoc)
     * @see org.eclipse.ui.ISaveablePart#isSaveAsAllowed()
     */
    public boolean isSaveAsAllowed() {
        return false;
    }

    /**
     * EditorEBhEɏݒs܂B
     *
     * @param site TCg
     * @param input ͒l
     * @throws PartInitException ͒lݒ肪ُ̏ꍇ
     */
    public void init(IEditorSite site, IEditorInput input)
        throws PartInitException {
        setSite(site);
        setInput(input);
        setPartName(input.getName());
    }
}

==> netjfwatcher_jetty_1.1.2_plugins.zip: netjfwatcher/jetty/gui/AbstractEditorView.java <==
/*
 * Created on 2006/08/17
 *
 *
 * Copyright(c) 2006 Yoshimasa Matsumoto
 */
package netjfwatcher.jetty.gui;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.jface.action.SubStatusLineManager;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorSite;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.part.EditorPart;


/**
 * Editor View`钊ۃNXłB
 *
 * @author Yoshimasa Matsumoto
 * @version 1.0
 */
public abstract class AbstractEditorView extends EditorPart {
	/** zFColor` */
	protected static Color whiteColor = new Color(null, 255, 255, 255);

    /* Xe[^XC}l[W */
    protected SubStatusLineManager statusLineManager;

    public AbstractEditorView() {
    }

    /**
     * PartControl𐶐܂B
     *
     * @param parent Composite
     */
    abstract public void createPartControl(Composite parent);

    /**
     * Xe[^XC\Zbg܂B
     *
     */
    protected abstract void setStatusLine();

    /**
     * tH[JXZbg̏łB
     */
    public void setFocus() {
    }

    /*
     *  (non-Javadoc)
     * @see org.eclipse.ui.ISaveablePart#isDirty()
     */
    public boolean isDirty() {
        return false;
    }

    /*
     *  (non-Javadoc)
     * @see org.eclipse.ui.ISaveablePart#doSave(org.eclipse.core.runtime.IProgressMonitor)
     */
    public void doSave(IProgressMonitor monitor) {
    }

    /*
     *  (non-Javadoc)
     * @see org.eclipse.ui.ISaveablePart#doSaveAs()
     */
    public void doSaveAs() {
    }

    /*
     *  (non-Javadoc)
     * @see org.eclipse.ui.ISaveablePart#isSaveAsAllowed()
     */
    public boolean isSaveAsAllowed() {
        return false;
    }

    /**
     * EditorEBhEɏݒs܂B
     *
     * @param site TCg
     * @param input ͒l
     * @throws PartInitException ͒lݒ肪ُ̏ꍇ
     */
    public void init(IEditorSite site, IEditorInput input)
        throws PartInitException {
        setSite(site);
        setInput(input);
        setPartName(input.getName());
    }
}
